Log2Map

Struct Log2Map 

pub struct Log2Map { /* private fields */ }
Logarithmic mapping using log2. This is useful for frequency (Hz) values.

Implementations

Source

impl Log2Map

pub fn new(min: f64, max: f64) -> Self

Create a new Log2Map for logarithmic mapping using log2. This is useful for frequency (Hz) values.

Arguments
  • min - the minimum of the range, must be > 0.0
  • max - the maximum of the range, must be > 0.0
Panics
  • Panics when either min or max <= 0.0.
pub fn normalize(&self, value: f64) -> f64

Map an f64 value to the normalized range [0.0, 1.0].

pub fn normalize_array(&self, in_values: &[f64], out_normalized: &mut [f64])

Map an array of f64 values to the normalized range [0.0, 1.0].

Values will be processed up to the length of the shortest array.

pub fn denormalize(&self, normalized: f64) -> f64

Un-map a normalized value to the corresponding f64 value.

pub fn denormalize_array(&self, in_normalized: &[f64], out_values: &mut [f64])

Un-map an array of normalized values to the corresponding f64 value.

Values will be processed up to the length of the shortest array.